summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autofill/autofill_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/autofill/autofill_manager.h')
-rw-r--r--chrome/browser/autofill/autofill_manager.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/autofill/autofill_manager.h b/chrome/browser/autofill/autofill_manager.h
index 9d44a92..aff0abc 100644
--- a/chrome/browser/autofill/autofill_manager.h
+++ b/chrome/browser/autofill/autofill_manager.h
@@ -171,9 +171,10 @@ class AutoFillManager : public TabContentsObserver,
AutoFillType type,
webkit_glue::FormField* field);
// Set |field| argument's value for phone number based on contents of the
// |profile|.
void FillPhoneNumberField(const AutoFillProfile* profile,
+ AutoFillType type,
webkit_glue::FormField* field);
// Parses the forms using heuristic matching and querying the AutoFill server.
@@ -171,9 +171,10 @@ class AutoFillManager : public TabContentsObserver,
AutoFillType type,
webkit_glue::FormField* field);
- // Set |field| argument's value for phone number based on contents of the
- // |profile|.
+ // Set |field| argument's value for phone/fax number based on contents of the
+ // |profile|. |type| is the type of the phone.
void FillPhoneNumberField(const AutoFillProfile* profile,